#!/bin/sh
#devine.tcl
# \
exec wish "$0" ${1+"$@"}

#*************************************************************************
#  Copyright (C) 2002 André Connes <andre.connes@wanadoo.fr>
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  any later version.
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
# 
#**************************************************************************
#  File  : devine.tcl
#  Author  : André Connes <andre.connes@wanadoo.fr>
#  Modifier:
#  Date    : 15/04/2003 modifié le 06/12/2004
#  Licence : GNU/GPL Version 2 ou plus
# 
#  Description:
#  ------------
# 
#  @version    $Id: devine.tcl,v 1.16 2006/03/25 00:55:15 abuledu_francois Exp $
#  @author     André Connes
#  @modifier   
#  @project    Le terrier
#  @copyright  André Connes
# 
#***********************************************************************
global sysFont glob

source devine.conf
source msg.tcl
source aider.tcl
source fonts.tcl
source lanceapplication.tcl

# gestion de l'espace de l'utilisateur
  if {![file exists [file join  $glob(home_devine)]]} {
	catch { file mkdir [file join $glob(home_devine)]}
  }
  if {![file exists [file join  $glob(home_reglages)]]} {
	catch { file mkdir [file join $glob(home_reglages)] }
  }
  #
  # langue par defaut
  #
  if {![file exists [file join  $glob(home_reglages) lang.conf]]} {
	set f [open [file join $glob(home_reglages) lang.conf] "w"]
      if { $glob(platform) == "windows" } {
		puts $f "fr"
      } else {
  		puts $f [string range $env(LANG) 0 1]
      }
      close $f
  }
  set f [open [file join $glob(home_reglages) lang.conf] "r"]
  gets $f lang
  close $f

  ::msgcat::mclocale $lang
  ::msgcat::mcload [file join [file dirname [info script]] msgs]

source fin_sequence.tcl

  if {![file exists [file join  $glob(home_reglages) dir_exos.conf]]} {
	set f [open [file join $glob(home_reglages) dir_exos.conf] "w"]
	puts $f "Commun"
	close $f
  }

  catch { file mkdir [file join $glob(home_msgs)] }
  # astuce suivante : ajoute automatiquement toute nouvelle langue chez l'utilisateur
  foreach f [glob [file join msgs *.msg]] {
	catch { file copy [file join $f] [file join $glob(home_msgs)]}
  }
  #
  # Etat des boutons des menus
  #
  set glob(etat_boutons) normal
  set rdir $glob(home_reglages)

  #set nom_utilisateur defaut
  #set classe defaut
  
  if { $glob(autorise) } {
    # recherche du repertoire de reglage de la classe
    if {[file exists /usr/share/abuledu/applications/abuledu-devine]} {
      set rdir "/usr/share/abuledu/applications/abuledu-devine/reglages"
    }
    if {[file exists /usr/share/abuledu-devine]} {
      set rdir "/usr/share/abuledu-devine/reglages"
    }
  }

  set glob(etat_boutons) normal

proc setlang {lang} {
  global env glob
  set env(LANG) $lang
  catch {set f [open [file join $glob(home_reglages) lang.conf] "w"]}
  puts $f [file rootname [file tail $lang]]
  close $f
}

#########################################################

proc charge_image {} {
  set types {{{Fichiers images} {.jpg .png .gif}}}
  set file [tk_getOpenFile -initialdir [file join images] -filetypes $types]
  if {$file != ""} {
    if {![file exists [file join images [file tail $file]]]} {
      file copy $file [file join images [file tail $file]]
    } else {
      #tk_messageBox -message "Le fichier ne sera pas copi dans le rpertoire images car il existe dj un fichier du mme nom"
    }
    lanceappli editeur_image.tcl [file tail $file]
  }
}

#########################################################
#
#               main_loop
#
#########################################################

proc main_loop {} {
  global . sysFont glob env

  #
  # Creation du menu utilise comme barre de menu:
  #
  catch {destroy .menu}
  catch { destroy .frame.c}
  catch {destroy .frame}
  menu .menu -tearoff 0

  #
  # Creation du menu Fichier
  #
  menu .menu.fichier -tearoff 0
  .menu add cascade -state $glob(etat_boutons) \
	-label [mc Fichier] -menu .menu.fichier

  set etat_fichier "normal"

  .menu.fichier add command -label [mc Ouvrir] -command charge_image
  .menu.fichier add command -label [mc Quitter] -command exit


  #
  # Creation du menu Reglages
  #
  menu .menu.reglages -tearoff 0
  .menu add cascade -state $glob(etat_boutons) \
	-label [mc Reglages] -menu .menu.reglages

  set etat_reglages "normal"

  # langues
  menu .menu.reglages.lang -tearoff 0 
  .menu.reglages add cascade -label "[mc Langue]" -menu .menu.reglages.lang

  foreach i [glob [file join  $glob(home_msgs) *.msg]] {
    set langue [string map {.msg "" } [file tail $i]]
    .menu.reglages.lang add radio -label $langue -variable langue -command "setlang $langue; lanceappli editeur.tcl 0"
  }

  #
  # Creation du menu aide
  #
  menu .menu.aide -tearoff 0
  .menu add cascade -state $glob(etat_boutons) \
	-label [mc Aide] -menu .menu.aide
  set l_langues [glob  [file join [pwd] aides aide2.*.html]]
  foreach langue $l_langues {
    set lang [lindex [split $langue "."] end-1]
    .menu.aide add command -label "[mc Aide] $lang" -command "aider $lang 2"
  }
  .menu.aide add command -label [mc {A_propos ...}] -command "source apropos.tcl"

  . configure -menu .menu

  #######################################################################"
  frame .frame -background blue
  pack .frame -side top -fill both -expand yes
  ###################On crée un canvas####################################

  canvas .frame.image -bg blue -highlightbackground blue
  pack .frame.image -expand true

  #
  # afficher l'image du terrier
  #
  set myimage [image create photo -file sysdata/background.png]
  label .frame.image.imagedisplayer -image $myimage -background blue
  grid .frame.image.imagedisplayer -column 3 -row 0 -sticky e

} ;# main_loop

########################################################################"

  # Nom de l'utilisateur par défaut sous windows
  if {$glob(platform) == "windows"} {
    set nom eleve
    # sauver le réglage du nom
    catch {set f [open [file join $glob(home_devine) reglages trace_user] "w"]}
    puts $f "$glob(trace_dir)/$nom"
    close $f
  }

bind . <Control-q> {exit}

#wm resizable . 0 0
wm geometry . 400x400+0+0
. configure -background blue
wm title . "[mc title_ed]"

main_loop
